DeltaBuffer

Trait DeltaBuffer 

pub trait DeltaBuffer {
    // Required methods
    fn len(&self) -> usize;
    fn get(&self, i: usize) -> Δ
}
DeltaBuffer trait adds methods to various size buffers that holds deltas

Required Methods

fn len(&self) -> usize

len tells the length of the delta buffer

fn get(&self, i: usize) -> &Delta

get gets a delta by index from the delta buffer

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl DeltaBuffer for [Delta; 1]

Source

fn len(&self) -> usize

len tells the length of the delta buffer

Source

fn get(&self, i: usize) -> &Delta

get gets a delta by index from the delta buffer

Source

impl DeltaBuffer for [Delta; 4]

Source

fn len(&self) -> usize

len tells the length of the delta buffer

Source

fn get(&self, i: usize) -> &Delta

get gets a delta by index from the delta buffer

Source

impl DeltaBuffer for [Delta; 8]

Source

fn len(&self) -> usize

len tells the length of the delta buffer

Source

fn get(&self, i: usize) -> &Delta

get gets a delta by index from the delta buffer

Implementors