[−][src]Trait rustenginelib::piece::FigureTrait
FigureTrait adds methods to Figure
Required methods
fn symbol(self) -> &'static str
returns the fen symbol for the figure ( lower case )
fn base_figure(self) -> Figure
returns the base figure of the figure, same as figure except for lancers, where it is LANCER
fn lancer_direction(self) -> usize
return the lancer direction of the figure provided that it is a lancer
Implementors
impl FigureTrait for Figure[src]
fn symbol(self) -> &'static str[src]
returns the fen symbol for the figure ( lower case )
fn base_figure(self) -> Figure[src]
returns the base figure of the figure, same as figure except for lancers, where it is LANCER
fn lancer_direction(self) -> usize[src]
return the lancer direction of the figure provided that it is a lancer